@@ -1,16 +1,7 @@
 /*
- *
- * Copyright (C) 2006-2008 Sebastian Trueg <trueg@k3b.org>
- *
- * This file is part of the K3b project.
- * Copyright (C) 1998-2008 Sebastian Trueg <trueg@k3b.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- * See the file "COPYING" for the exact licensing terms.
- */
+    SPDX-FileCopyrightText: 1998-2008 Sebastian Trueg <trueg@k3b.org>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "k3bintmapcombobox.h"
 
@@ -124,7 +115,7 @@ bool K3b::IntMapComboBox::insertItem( int value, const QString& text, const QStr
         index = QComboBox::count();
     }
 
-    d->values.insert( index, qMakePair<int, QString>( value, description ) );
+    d->values.insert( index, qMakePair( value, description ) );
     d->buildValueIndexMap();
 
     QComboBox::insertItem( index, text );
@@ -159,4 +150,4 @@ void K3b::IntMapComboBox::addGlobalWhatsThisText( const QString& top, const QStr
     d->updateWhatsThis();
 }
 
-
+#include "moc_k3bintmapcombobox.cpp"
